ludolph-skeleton
################

`Ludolph <https://github.com/erigones/Ludolph>`_: Skeleton plugin

Sample plugin that provides directory structure for Ludolph plugins and basic command examples.

.. image:: https://badge.fury.io/py/ludolph-skeleton.png
    :target: http://badge.fury.io/py/ludolph-skeleton


Installation
------------

- Install the latest released version using pip::

    pip install ludolph-skeleton

- Add new plugin section into Ludolph configuration file::

    [ludolph_skeleton.hello_world]

- Reload Ludolph::

    service ludolph reload


**Dependencies:**

- `Ludolph <https://github.com/erigones/Ludolph>`_ (0.6.0+)


Links
-----

- Wiki: https://github.com/erigones/Ludolph/wiki/How-to-create-a-plugin#create-3rd-party-plugin
- Bug Tracker: https://github.com/erigones/ludolph-skeleton/issues
- Google+ Community: https://plus.google.com/u/0/communities/112192048027134229675
- Twitter: https://twitter.com/erigones


License
-------

For more information see the `LICENSE <https://github.com/erigones/ludolph-skeleton/blob/master/LICENSE>`_ file.

